'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function appendNode ( node, target ) {
	target.appendChild( node );
}

function insertNode ( node, target, anchor ) {
	target.insertBefore( node, anchor );
}

function detachNode ( node ) {
	node.parentNode.removeChild( node );
}

function createElement ( name ) {
	return document.createElement( name );
}

function createText ( data ) {
	return document.createTextNode( data );
}

function createComment () {
	return document.createComment( '' );
}

function addEventListener ( node, event, handler ) {
	node.addEventListener ( event, handler, false );
}

function removeEventListener ( node, event, handler ) {
	node.removeEventListener ( event, handler, false );
}

function setAttribute ( node, attribute, value ) {
	node.setAttribute ( attribute, value );
}

function get ( key ) {
	return key ? this._state[ key ] : this._state;
}

function fire ( eventName, data ) {
	var handlers = eventName in this._handlers && this._handlers[ eventName ].slice();
	if ( !handlers ) return;

	for ( var i = 0; i < handlers.length; i += 1 ) {
		handlers[i].call( this, data );
	}
}

function observe ( key, callback, options ) {
	var group = ( options && options.defer ) ? this._observers.pre : this._observers.post;

	( group[ key ] || ( group[ key ] = [] ) ).push( callback );

	if ( !options || options.init !== false ) {
		callback.__calling = true;
		callback.call( this, this._state[ key ] );
		callback.__calling = false;
	}

	return {
		cancel: function () {
			var index = group[ key ].indexOf( callback );
			if ( ~index ) group[ key ].splice( index, 1 );
		}
	};
}

function on ( eventName, handler ) {
	if ( eventName === 'teardown' ) return this.on( 'destroy', handler );

	var handlers = this._handlers[ eventName ] || ( this._handlers[ eventName ] = [] );
	handlers.push( handler );

	return {
		cancel: function () {
			var index = handlers.indexOf( handler );
			if ( ~index ) handlers.splice( index, 1 );
		}
	};
}

function set ( newState ) {
	this._set( newState );
	( this._root || this )._flush();
}

function _flush () {
	if ( !this._renderHooks ) return;

	while ( this._renderHooks.length ) {
		var hook = this._renderHooks.pop();
		hook.fn.call( hook.context );
	}
}

var proto = {
	get: get,
	fire: fire,
	observe: observe,
	on: on,
	set: set,
	_flush: _flush
};

function noop () {}

function dispatchObservers ( component, group, newState, oldState ) {
	for ( var key in group ) {
		if ( !( key in newState ) ) continue;

		var newValue = newState[ key ];
		var oldValue = oldState[ key ];

		if ( newValue === oldValue && typeof newValue !== 'object' ) continue;

		var callbacks = group[ key ];
		if ( !callbacks ) continue;

		for ( var i = 0; i < callbacks.length; i += 1 ) {
			var callback = callbacks[i];
			if ( callback.__calling ) continue;

			callback.__calling = true;
			callback.call( component, newValue, oldValue );
			callback.__calling = false;
		}
	}
}

function renderMainFragment$1 ( root, component ) {
	var button = createElement( 'button' );
	button.type = "button";
	button.className = "close";
	setAttribute( button, 'aria-label', "Close" );
	
	function clickHandler ( event ) {
		component.fire('click');
	}
	
	addEventListener( button, 'click', clickHandler );
	
	var span = createElement( 'span' );
	setAttribute( span, 'aria-hidden', "true" );
	
	appendNode( span, button );
	appendNode( createText( "×" ), span );

	return {
		mount: function ( target, anchor ) {
			insertNode( button, target, anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			removeEventListener( button, 'click', clickHandler );
			
			if ( detach ) {
				detachNode( button );
			}
		}
	};
}

function Close ( options ) {
	options = options || {};
	this._state = options.data || {};
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$1( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Close.prototype = Object.assign( {}, proto );

Close.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Close.prototype.teardown = Close.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template = (function () {
  // TODO handle fade transition when dismissing

  return {
    components: {
      Close
    },
    data() {
      return {
        class: '',
        color: 'success',
        isOpen: true,
        dismissible: false
      };
    }
  }
}());

function renderMainFragment ( root, component ) {
	var ifBlock_anchor = createComment();
	
	function getBlock ( root ) {
		if ( root.isOpen ) return renderIfBlock_0;
		return null;
	}
	
	var currentBlock = getBlock( root );
	var ifBlock = currentBlock && currentBlock( root, component );

	return {
		mount: function ( target, anchor ) {
			insertNode( ifBlock_anchor, target, anchor );
			if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			var _currentBlock = currentBlock;
			currentBlock = getBlock( root );
			if ( _currentBlock === currentBlock && ifBlock) {
				ifBlock.update( changed, root );
			} else {
				if ( ifBlock ) ifBlock.teardown( true );
				ifBlock = currentBlock && currentBlock( root, component );
				if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock ) ifBlock.teardown( detach );
			
			if ( detach ) {
				detachNode( ifBlock_anchor );
			}
		}
	};
}

function renderIfBlock_0 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "alert alert-" + ( root.color ) + ( root.dismissible ? ' alert-dismissible' : '' ) + " " + ( root.class );
	setAttribute( div, 'role', "alert" );
	
	var ifBlock1_anchor = createComment();
	appendNode( ifBlock1_anchor, div );
	
	function getBlock1 ( root ) {
		if ( root.dismissible ) return renderIfBlock1_0;
		return null;
	}
	
	var currentBlock1 = getBlock1( root );
	var ifBlock1 = currentBlock1 && currentBlock1( root, component );
	
	if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );
	appendNode( createText( "\n    " ), div );
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "alert alert-" + ( root.color ) + ( root.dismissible ? ' alert-dismissible' : '' ) + " " + ( root.class );
			
			var _currentBlock1 = currentBlock1;
			currentBlock1 = getBlock1( root );
			if ( _currentBlock1 === currentBlock1 && ifBlock1) {
				ifBlock1.update( changed, root );
			} else {
				if ( ifBlock1 ) ifBlock1.teardown( true );
				ifBlock1 = currentBlock1 && currentBlock1( root, component );
				if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock1 ) ifBlock1.teardown( false );
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock1_0 ( root, component ) {
	var close = new template.components.Close({
		target: null,
		_root: component._root || component
	});
	
	close.on( 'click', function ( event ) {
		component.set({ isOpen: false });
	});

	return {
		mount: function ( target, anchor ) {
			close._fragment.mount( target, anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			close.destroy( detach );
		}
	};
}

function Alert ( options ) {
	options = options || {};
	this._state = Object.assign( template.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	this._renderHooks = [];
	
	this._fragment = renderMainFragment( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
	
	this._flush();
}

Alert.prototype = Object.assign( {}, proto );

Alert.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
	
	this._flush();
};

Alert.prototype.teardown = Alert.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$1 = (function () {
  return {
    data() {
      return {
        class: '',
        color: 'default',
        pill: false
      };
    }
  };
}());

function renderMainFragment$2 ( root, component ) {
	var span = createElement( 'span' );
	span.className = "badge badge-" + ( root.color ) + ( root.pill ? ' badge-pill' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, span );

	return {
		mount: function ( target, anchor ) {
			insertNode( span, target, anchor );
			component._yield && component._yield.mount( span, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			span.className = "badge badge-" + ( root.color ) + ( root.pill ? ' badge-pill' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( span );
			}
		}
	};
}

function Badge ( options ) {
	options = options || {};
	this._state = Object.assign( template$1.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$2( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Badge.prototype = Object.assign( {}, proto );

Badge.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Badge.prototype.teardown = Badge.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$2 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$3 ( root, component ) {
	var ol = createElement( 'ol' );
	ol.className = "breadcrumb " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, ol );

	return {
		mount: function ( target, anchor ) {
			insertNode( ol, target, anchor );
			component._yield && component._yield.mount( ol, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			ol.className = "breadcrumb " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( ol );
			}
		}
	};
}

function Breadcrumb ( options ) {
	options = options || {};
	this._state = Object.assign( template$2.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$3( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Breadcrumb.prototype = Object.assign( {}, proto );

Breadcrumb.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Breadcrumb.prototype.teardown = Breadcrumb.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$3 = (function () {
  return {
    data() {
      return {
        active: false,
        class: ''
      }
    }
  }
}());

function renderMainFragment$4 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "breadcrumb-item" + ( root.active ? ' active' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "breadcrumb-item" + ( root.active ? ' active' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function BreadcrumbItem ( options ) {
	options = options || {};
	this._state = Object.assign( template$3.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$4( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

BreadcrumbItem.prototype = Object.assign( {}, proto );

BreadcrumbItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

BreadcrumbItem.prototype.teardown = BreadcrumbItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$4 = (function () {
  return {
    methods: {
      onClick(e) {
        const { disabled } = this.get();
        if (disabled) {
          e.preventDefault();
          return;
        } else {
          this.fire('click', e);
        }
      }
    },
    data() {
      return {
        active: false,
        block: false,
        class: '',
        color: 'secondary',
        outline: false,
        size: null
      }
    }
  }
}());

function renderMainFragment$5 ( root, component ) {
	var Button = createElement( 'Button' );
	Button.className = "btn btn" + ( root.outline ? '-outline' : '' ) + "-" + ( root.color ) + ( root.size ? ` btn-${root.size}` : '' ) + ( root.block ? ' btn-block' : '' ) + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' );
	
	function clickHandler ( event ) {
		component.onClick(event);
	}
	
	addEventListener( Button, 'click', clickHandler );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, Button );

	return {
		mount: function ( target, anchor ) {
			insertNode( Button, target, anchor );
			component._yield && component._yield.mount( Button, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			Button.className = "btn btn" + ( root.outline ? '-outline' : '' ) + "-" + ( root.color ) + ( root.size ? ` btn-${root.size}` : '' ) + ( root.block ? ' btn-block' : '' ) + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' );
		},
		
		teardown: function ( detach ) {
			removeEventListener( Button, 'click', clickHandler );
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( Button );
			}
		}
	};
}

function Button ( options ) {
	options = options || {};
	this._state = Object.assign( template$4.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$5( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Button.prototype = Object.assign( {}, template$4.methods, proto );

Button.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Button.prototype.teardown = Button.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$5 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$6 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "" + ( root.size ? `btn-group-${root.size} ` : '' ) + ( root.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "" + ( root.size ? `btn-group-${root.size} ` : '' ) + ( root.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function ButtonGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$5.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$6( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ButtonGroup.prototype = Object.assign( {}, proto );

ButtonGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonGroup.prototype.teardown = ButtonGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$6 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$7 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "btn-toolbar " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "btn-toolbar " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function ButtonToolbar ( options ) {
	options = options || {};
	this._state = Object.assign( template$6.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$7( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ButtonToolbar.prototype = Object.assign( {}, proto );

ButtonToolbar.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonToolbar.prototype.teardown = ButtonToolbar.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$7 = (function () {
  return {
    data() {
      return {
        block: false,
        class: '',
        inverse: false,
        outline: false
      }
    }
  }
}());

function renderMainFragment$8 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card" + ( root.inverse ? ' card-inverse' : '' ) + ( root.block ? ' card-block' : '' ) + ( root.color ? ` card${root.outline ? '-outline' : ''}-${root.color}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card" + ( root.inverse ? ' card-inverse' : '' ) + ( root.block ? ' card-block' : '' ) + ( root.color ? ` card${root.outline ? '-outline' : ''}-${root.color}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Card ( options ) {
	options = options || {};
	this._state = Object.assign( template$7.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$8( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Card.prototype = Object.assign( {}, proto );

Card.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Card.prototype.teardown = Card.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$8 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$9 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-block " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-block " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardBlock ( options ) {
	options = options || {};
	this._state = Object.assign( template$8.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$9( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardBlock.prototype = Object.assign( {}, proto );

CardBlock.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardBlock.prototype.teardown = CardBlock.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$9 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$10 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-columns " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-columns " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardColumns ( options ) {
	options = options || {};
	this._state = Object.assign( template$9.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$10( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardColumns.prototype = Object.assign( {}, proto );

CardColumns.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardColumns.prototype.teardown = CardColumns.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$10 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$11 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-deck " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-deck " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardDeck ( options ) {
	options = options || {};
	this._state = Object.assign( template$10.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$11( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardDeck.prototype = Object.assign( {}, proto );

CardDeck.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardDeck.prototype.teardown = CardDeck.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$11 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$12 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-footer " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-footer " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardFooter ( options ) {
	options = options || {};
	this._state = Object.assign( template$11.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$12( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardFooter.prototype = Object.assign( {}, proto );

CardFooter.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardFooter.prototype.teardown = CardFooter.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$12 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$13 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-group " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-group " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$12.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$13( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardGroup.prototype = Object.assign( {}, proto );

CardGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardGroup.prototype.teardown = CardGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$13 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$14 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-header " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-header " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardHeader ( options ) {
	options = options || {};
	this._state = Object.assign( template$13.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$14( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardHeader.prototype = Object.assign( {}, proto );

CardHeader.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardHeader.prototype.teardown = CardHeader.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$14 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$15 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "card-img-overlay " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "card-img-overlay " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function CardImgOverlay ( options ) {
	options = options || {};
	this._state = Object.assign( template$14.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$15( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardImgOverlay.prototype = Object.assign( {}, proto );

CardImgOverlay.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardImgOverlay.prototype.teardown = CardImgOverlay.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$15 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$16 ( root, component ) {
	var h6 = createElement( 'h6' );
	h6.className = "card-subtitle " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, h6 );

	return {
		mount: function ( target, anchor ) {
			insertNode( h6, target, anchor );
			component._yield && component._yield.mount( h6, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			h6.className = "card-subtitle " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( h6 );
			}
		}
	};
}

function CardSubtitle ( options ) {
	options = options || {};
	this._state = Object.assign( template$15.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$16( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardSubtitle.prototype = Object.assign( {}, proto );

CardSubtitle.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardSubtitle.prototype.teardown = CardSubtitle.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$16 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$17 ( root, component ) {
	var p = createElement( 'p' );
	p.className = "card-text " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, p );

	return {
		mount: function ( target, anchor ) {
			insertNode( p, target, anchor );
			component._yield && component._yield.mount( p, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			p.className = "card-text " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( p );
			}
		}
	};
}

function CardText ( options ) {
	options = options || {};
	this._state = Object.assign( template$16.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$17( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardText.prototype = Object.assign( {}, proto );

CardText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardText.prototype.teardown = CardText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$17 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$18 ( root, component ) {
	var h4 = createElement( 'h4' );
	h4.className = "card-title " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, h4 );

	return {
		mount: function ( target, anchor ) {
			insertNode( h4, target, anchor );
			component._yield && component._yield.mount( h4, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			h4.className = "card-title " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( h4 );
			}
		}
	};
}

function CardTitle ( options ) {
	options = options || {};
	this._state = Object.assign( template$17.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$18( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

CardTitle.prototype = Object.assign( {}, proto );

CardTitle.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardTitle.prototype.teardown = CardTitle.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

function applyComputations ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'widths' in newState && typeof state.widths === 'object' || state.widths !== oldState.widths ) || ( 'xs' in newState && typeof state.xs === 'object' || state.xs !== oldState.xs ) || ( 'sm' in newState && typeof state.sm === 'object' || state.sm !== oldState.sm ) || ( 'md' in newState && typeof state.md === 'object' || state.md !== oldState.md ) || ( 'lg' in newState && typeof state.lg === 'object' || state.lg !== oldState.lg ) || ( 'xl' in newState && typeof state.xl === 'object' || state.xl !== oldState.xl ) ) {
		state.classes = newState.classes = template$18.computed.classes( state.widths, state.xs, state.sm, state.md, state.lg, state.xl );
	}
}

var template$18 = (function () {
  const widths = ['xs', 'sm', 'md', 'lg', 'xl'];

  function isObject(value) {
    const type = typeof value;
    return value != null && (type == 'object' || type == 'function');
  }

  const getColumnSizeClass = (isXs, colWidth, colSize) => {
    if (colSize === true || colSize === '') {
      return isXs ? 'col' : `col-${colWidth}`;
    } else if (colSize === 'auto') {
      return isXs ? 'col-auto' : `col-${colWidth}-auto`;
    }

    return isXs ? `col-${colSize}` : `col-${colWidth}-${colSize}`;
  };

  return {
    data() {
      return {
        class: '',
        widths
      }
    },
    computed: {
      classes(widths, xs, sm, md, lg, xl) {
        const colClasses = [];
        const props = {
          xs,
          sm,
          md,
          lg,
          xl
        };

        widths.forEach((colWidth, i) => {
          let columnProp = props[colWidth];

          if (!i && columnProp === undefined) {
            columnProp = true;
          }

          if (!columnProp) {
            return;
          }

          const isXs = !i;
          let colClass;

          if (isObject(columnProp)) {
            const colSizeInterfix = isXs ? '-' : `-${colWidth}-`;
            colClass = getColumnSizeClass(isXs, colWidth, columnProp.size);

            if (columnProp.size || columnProp.size === '') colClasses.push(colClass);
            if (columnProp.push) colClasses.push(`push${colSizeInterfix}${columnProp.push}`);
            if (columnProp.pull) colClasses.push(`pull${colSizeInterfix}${columnProp.pull}`);
            if (columnProp.offset) colClasses.push(`offset${colSizeInterfix}${columnProp.offset}`);
          } else {
            colClass = getColumnSizeClass(isXs, colWidth, columnProp);
            colClasses.push(colClass);
          }
        });
        
        return colClasses.join(' ');
      }
    }
  }
}());

function renderMainFragment$19 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "" + ( root.classes ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "" + ( root.classes ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Col ( options ) {
	options = options || {};
	this._state = Object.assign( template$18.data(), options.data );
	applyComputations( this._state, this._state, {}, true );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$19( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Col.prototype = Object.assign( {}, proto );

Col.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	applyComputations( this._state, newState, oldState, false );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Col.prototype.teardown = Col.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$19 = (function () {
  return {
    data() {
      return {
        class: '',
        fluid: false
      }
    }
  };
}());

function renderMainFragment$20 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "container" + ( root.fluid ? '-fluid' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "container" + ( root.fluid ? '-fluid' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Container ( options ) {
	options = options || {};
	this._state = Object.assign( template$19.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$20( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Container.prototype = Object.assign( {}, proto );

Container.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Container.prototype.teardown = Container.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$20 = (function () {
  return {
    data() {
      return {
        class: '',
        inline: false
      }
    }
  }
}());

function renderMainFragment$21 ( root, component ) {
	var form = createElement( 'form' );
	form.className = "" + ( root.inline ? 'form-inline' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, form );

	return {
		mount: function ( target, anchor ) {
			insertNode( form, target, anchor );
			component._yield && component._yield.mount( form, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			form.className = "" + ( root.inline ? 'form-inline' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( form );
			}
		}
	};
}

function Form ( options ) {
	options = options || {};
	this._state = Object.assign( template$20.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$21( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Form.prototype = Object.assign( {}, proto );

Form.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Form.prototype.teardown = Form.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$21 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$22 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "form-control-feedback " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "form-control-feedback " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function FormFeedback ( options ) {
	options = options || {};
	this._state = Object.assign( template$21.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$22( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

FormFeedback.prototype = Object.assign( {}, proto );

FormFeedback.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormFeedback.prototype.teardown = FormFeedback.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$22 = (function () {
  return {
    data() {
      return {
        check: false,
        class: '',
        color: null,
        disabled: false,
        row: false
      }
    }
  }
}());

function renderMainFragment$23 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "" + ( root.color ? `has-${root.color}` : '' ) + ( root.row ? ' row' : '' ) + ( root.check ? ' form-check' : ' form-group' ) + ( root.check && root.disabled ? ' disabled' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "" + ( root.color ? `has-${root.color}` : '' ) + ( root.row ? ' row' : '' ) + ( root.check ? ' form-check' : ' form-group' ) + ( root.check && root.disabled ? ' disabled' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function FormGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$22.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$23( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

FormGroup.prototype = Object.assign( {}, proto );

FormGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormGroup.prototype.teardown = FormGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$23 = (function () {
  return {
    data() {
      return {
        class: '',
        color: null,
        inline: false
      }
    }
  }
}());

function renderMainFragment$24 ( root, component ) {
	var small = createElement( 'small' );
	small.className = "" + ( !root.inline ? 'form-text' : '' ) + ( root.color ? ` text-${root.color}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, small );

	return {
		mount: function ( target, anchor ) {
			insertNode( small, target, anchor );
			component._yield && component._yield.mount( small, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			small.className = "" + ( !root.inline ? 'form-text' : '' ) + ( root.color ? ` text-${root.color}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( small );
			}
		}
	};
}

function FormText ( options ) {
	options = options || {};
	this._state = Object.assign( template$23.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$24( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

FormText.prototype = Object.assign( {}, proto );

FormText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormText.prototype.teardown = FormText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$24 = (function () {
  return {
    data() {
      return {
        border: false,
        class: '',
        fixedWidth: false,
        flip: false,
        inverse: false,
        pulse: false,
        rotate: false,
        size: false,
        spin: false,
        stack: false
      }
    }
  }
}());

function renderMainFragment$25 ( root, component ) {
	var i = createElement( 'i' );
	i.className = "fa fa-" + ( root.name ) + ( root.size ? ' fa-' + root.size : '' ) + ( root.spin ? ' fa-spin' : '' ) + ( root.pulse ? ' fa-pulse' : '' ) + ( root.border ? ' fa-border' : '' ) + ( root.fixedWidth ? ' fa-fw' : '' ) + ( root.inverse ? ' fa-inverse' : '' ) + ( root.flip ? ' fa-flip-' + root.flip : '' ) + ( root.rotate ? ' fa-rotate-' + root.rotate : '' ) + ( root.stack ? ' fa-stack-' + root.stack : '' ) + " " + ( root.class );

	return {
		mount: function ( target, anchor ) {
			insertNode( i, target, anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			i.className = "fa fa-" + ( root.name ) + ( root.size ? ' fa-' + root.size : '' ) + ( root.spin ? ' fa-spin' : '' ) + ( root.pulse ? ' fa-pulse' : '' ) + ( root.border ? ' fa-border' : '' ) + ( root.fixedWidth ? ' fa-fw' : '' ) + ( root.inverse ? ' fa-inverse' : '' ) + ( root.flip ? ' fa-flip-' + root.flip : '' ) + ( root.rotate ? ' fa-rotate-' + root.rotate : '' ) + ( root.stack ? ' fa-stack-' + root.stack : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			if ( detach ) {
				detachNode( i );
			}
		}
	};
}

function Icon ( options ) {
	options = options || {};
	this._state = Object.assign( template$24.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$25( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Icon.prototype = Object.assign( {}, proto );

Icon.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Icon.prototype.teardown = Icon.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$25 = (function () {
  return {
    data() {
      return {
        class: '',
        size: null
      }
    }
  }
}());

function renderMainFragment$26 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "input-group" + ( root.size ? ` input-group-${root.size}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "input-group" + ( root.size ? ` input-group-${root.size}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function InputGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$25.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$26( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

InputGroup.prototype = Object.assign( {}, proto );

InputGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

InputGroup.prototype.teardown = InputGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$26 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$27 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "input-group-addon " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "input-group-addon " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function InputGroupAddon ( options ) {
	options = options || {};
	this._state = Object.assign( template$26.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$27( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

InputGroupAddon.prototype = Object.assign( {}, proto );

InputGroupAddon.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

InputGroupAddon.prototype.teardown = InputGroupAddon.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$27 = (function () {
  return {
    data() {
      return {
        class: '',
        fluid: false
      }
    }
  }
}());

function renderMainFragment$28 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "jumbotron" + ( root.fluid ? ' jumbotron-fluid' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "jumbotron" + ( root.fluid ? ' jumbotron-fluid' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Jumbotron ( options ) {
	options = options || {};
	this._state = Object.assign( template$27.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$28( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Jumbotron.prototype = Object.assign( {}, proto );

Jumbotron.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Jumbotron.prototype.teardown = Jumbotron.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$28 = (function () {
  return {
    data() {
      return {
        class: '',
        flush: false
      }
    }
  }
}());

function renderMainFragment$29 ( root, component ) {
	var ul = createElement( 'ul' );
	ul.className = "list-group" + ( root.flush ? ' list-group-flush' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, ul );

	return {
		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			component._yield && component._yield.mount( ul, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			ul.className = "list-group" + ( root.flush ? ' list-group-flush' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( ul );
			}
		}
	};
}

function ListGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$28.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$29( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroup.prototype = Object.assign( {}, proto );

ListGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroup.prototype.teardown = ListGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$29 = (function () {
  return {
    data() {
      return {
        active: false,
        class: '',
        disabled: false,
        action: false,
        color: false
      }
    }
  }
}());

function renderMainFragment$30 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "list-group-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + ( root.action ? ' list-group-item-action' : '' ) + ( root.color ? ` list-group-item-${root.color}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "list-group-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + ( root.action ? ' list-group-item-action' : '' ) + ( root.color ? ` list-group-item-${root.color}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function ListGroupItem ( options ) {
	options = options || {};
	this._state = Object.assign( template$29.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$30( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroupItem.prototype = Object.assign( {}, proto );

ListGroupItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItem.prototype.teardown = ListGroupItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$30 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$31 ( root, component ) {
	var h5 = createElement( 'h5' );
	h5.className = "list-group-item-heading " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, h5 );

	return {
		mount: function ( target, anchor ) {
			insertNode( h5, target, anchor );
			component._yield && component._yield.mount( h5, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			h5.className = "list-group-item-heading " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( h5 );
			}
		}
	};
}

function ListGroupItemHeading ( options ) {
	options = options || {};
	this._state = Object.assign( template$30.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$31( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroupItemHeading.prototype = Object.assign( {}, proto );

ListGroupItemHeading.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItemHeading.prototype.teardown = ListGroupItemHeading.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$31 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$32 ( root, component ) {
	var p = createElement( 'p' );
	p.className = "list-group-item-text " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, p );

	return {
		mount: function ( target, anchor ) {
			insertNode( p, target, anchor );
			component._yield && component._yield.mount( p, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			p.className = "list-group-item-text " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( p );
			}
		}
	};
}

function ListGroupItemText ( options ) {
	options = options || {};
	this._state = Object.assign( template$31.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$32( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroupItemText.prototype = Object.assign( {}, proto );

ListGroupItemText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItemText.prototype.teardown = ListGroupItemText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$32 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  };
}());

function renderMainFragment$33 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "media " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "media " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Media ( options ) {
	options = options || {};
	this._state = Object.assign( template$32.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$33( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Media.prototype = Object.assign( {}, proto );

Media.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Media.prototype.teardown = Media.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$33 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  };
}());

function renderMainFragment$34 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "media-body " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "media-body " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function MediaBody ( options ) {
	options = options || {};
	this._state = Object.assign( template$33.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$34( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

MediaBody.prototype = Object.assign( {}, proto );

MediaBody.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

MediaBody.prototype.teardown = MediaBody.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$34 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$35 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "modal-footer " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "modal-footer " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function ModalFooter ( options ) {
	options = options || {};
	this._state = Object.assign( template$34.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$35( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ModalFooter.prototype = Object.assign( {}, proto );

ModalFooter.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ModalFooter.prototype.teardown = ModalFooter.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$35 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$36 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "nav-item " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "nav-item " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function NavDropdown ( options ) {
	options = options || {};
	this._state = Object.assign( template$35.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$36( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

NavDropdown.prototype = Object.assign( {}, proto );

NavDropdown.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavDropdown.prototype.teardown = NavDropdown.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$36 = (function () {
  return {
    data() {
      return {
        class: '',
        fill: false,
        justified: false,
        navbar: false,
        pills: false,
        tabs: false,
        vertical: false
      }
    }
  }
}());

function renderMainFragment$37 ( root, component ) {
	var ul = createElement( 'ul' );
	ul.className = "" + ( root.navbar ? 'navbar-nav' : 'nav' ) + ( root.tabs ? ' nav-tabs' : '' ) + ( root.pills ? ' nav-pills' : '' ) + ( root.fill ? ' nav-fill' : root.justified ? ' nav-justified' : '' ) + ( root.vertical ? ' flex-column' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, ul );

	return {
		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			component._yield && component._yield.mount( ul, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			ul.className = "" + ( root.navbar ? 'navbar-nav' : 'nav' ) + ( root.tabs ? ' nav-tabs' : '' ) + ( root.pills ? ' nav-pills' : '' ) + ( root.fill ? ' nav-fill' : root.justified ? ' nav-justified' : '' ) + ( root.vertical ? ' flex-column' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( ul );
			}
		}
	};
}

function Nav ( options ) {
	options = options || {};
	this._state = Object.assign( template$36.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$37( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Nav.prototype = Object.assign( {}, proto );

Nav.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Nav.prototype.teardown = Nav.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$37 = (function () {
  return {
    data() {
      return {
        active: false,
        class: ''
      }
    }
  }
}());

function renderMainFragment$38 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "nav-item" + ( root.active ? ' active' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "nav-item" + ( root.active ? ' active' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function NavItem ( options ) {
	options = options || {};
	this._state = Object.assign( template$37.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$38( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

NavItem.prototype = Object.assign( {}, proto );

NavItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavItem.prototype.teardown = NavItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$38 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$39 ( root, component ) {
	var a = createElement( 'a' );
	a.className = "navbar-brand " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, a );

	return {
		mount: function ( target, anchor ) {
			insertNode( a, target, anchor );
			component._yield && component._yield.mount( a, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			a.className = "navbar-brand " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( a );
			}
		}
	};
}

function NavbarBrand ( options ) {
	options = options || {};
	this._state = Object.assign( template$38.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$39( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

NavbarBrand.prototype = Object.assign( {}, proto );

NavbarBrand.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavbarBrand.prototype.teardown = NavbarBrand.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$39 = (function () {
  return {
    data() {
      return {
        class: '',
        size: null
      }
    }
  }
}());

function renderMainFragment$40 ( root, component ) {
	var ul = createElement( 'ul' );
	ul.className = "pagination" + ( root.size ? ` pagination-${root.size}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, ul );

	return {
		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			component._yield && component._yield.mount( ul, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			ul.className = "pagination" + ( root.size ? ` pagination-${root.size}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( ul );
			}
		}
	};
}

function Pagination ( options ) {
	options = options || {};
	this._state = Object.assign( template$39.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$40( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Pagination.prototype = Object.assign( {}, proto );

Pagination.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Pagination.prototype.teardown = Pagination.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$40 = (function () {
  return {
    data() {
      return {
        active: false,
        class: '',
        disabled: false
      }
    }
  }
}());

function renderMainFragment$41 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "page-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "page-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function PaginationItem ( options ) {
	options = options || {};
	this._state = Object.assign( template$40.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$41( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

PaginationItem.prototype = Object.assign( {}, proto );

PaginationItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

PaginationItem.prototype.teardown = PaginationItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$41 = (function () {
  // TODO add state to this component, generate PaginationItems, Links, on:click, etc
  return {
    data() {
      return {
        class: '',
        next: false,
        previous: false
      }
    }
  }
}());

function renderMainFragment$42 ( root, component ) {
	var a = createElement( 'a' );
	a.className = "page-link" + ( root.size ? ` pagination-${root.size}` : '' ) + " " + ( root.class );
	
	var ifBlock_anchor = createComment();
	appendNode( ifBlock_anchor, a );
	
	function getBlock ( root ) {
		if ( root.previous ) return renderIfBlock_0$1;
		if ( root.next ) return renderIfBlock_1;
		return renderIfBlock_2;
	}
	
	var currentBlock = getBlock( root );
	var ifBlock = currentBlock && currentBlock( root, component );
	
	if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );

	return {
		mount: function ( target, anchor ) {
			insertNode( a, target, anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			a.className = "page-link" + ( root.size ? ` pagination-${root.size}` : '' ) + " " + ( root.class );
			
			var _currentBlock = currentBlock;
			currentBlock = getBlock( root );
			if ( _currentBlock === currentBlock && ifBlock) {
				ifBlock.update( changed, root );
			} else {
				if ( ifBlock ) ifBlock.teardown( true );
				ifBlock = currentBlock && currentBlock( root, component );
				if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock ) ifBlock.teardown( false );
			
			if ( detach ) {
				detachNode( a );
			}
		}
	};
}

function renderIfBlock_2 ( root, component ) {
	var yield_anchor = createComment();

	return {
		mount: function ( target, anchor ) {
			insertNode( yield_anchor, target, anchor );
			component._yield && component._yield.mount( target, yield_anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( yield_anchor );
			}
		}
	};
}

function renderIfBlock_1 ( root, component ) {
	var text = createText( "»" );

	return {
		mount: function ( target, anchor ) {
			insertNode( text, target, anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			if ( detach ) {
				detachNode( text );
			}
		}
	};
}

function renderIfBlock_0$1 ( root, component ) {
	var text = createText( "«" );

	return {
		mount: function ( target, anchor ) {
			insertNode( text, target, anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			if ( detach ) {
				detachNode( text );
			}
		}
	};
}

function PaginationLink ( options ) {
	options = options || {};
	this._state = Object.assign( template$41.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$42( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

PaginationLink.prototype = Object.assign( {}, proto );

PaginationLink.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

PaginationLink.prototype.teardown = PaginationLink.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

/**
 * lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var objectToString = objectProto.toString;

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return !!value && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && objectToString.call(value) == symbolTag);
}

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

var index = toNumber;

function applyComputations$1 ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'value' in newState && typeof state.value === 'object' || state.value !== oldState.value ) || ( 'max' in newState && typeof state.max === 'object' || state.max !== oldState.max ) ) {
		state.percent = newState.percent = template$42.computed.percent( state.value, state.max );
	}
}

var template$42 = (function () {
return {
  data() {
    return {
      bar: false,
      class: '',
      value: 0,
      max: 100,
      multi: false
    }
  },
  computed: {
    percent(value, max) {
      return (index(value) / index(max)) * 100;
    }
  }
}
}());

function renderMainFragment$43 ( root, component ) {
	var ifBlock_anchor = createComment();
	
	function getBlock ( root ) {
		if ( !root.bar ) return renderIfBlock_0$2;
		return renderIfBlock_1$1;
	}
	
	var currentBlock = getBlock( root );
	var ifBlock = currentBlock && currentBlock( root, component );

	return {
		mount: function ( target, anchor ) {
			insertNode( ifBlock_anchor, target, anchor );
			if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			var _currentBlock = currentBlock;
			currentBlock = getBlock( root );
			if ( _currentBlock === currentBlock && ifBlock) {
				ifBlock.update( changed, root );
			} else {
				if ( ifBlock ) ifBlock.teardown( true );
				ifBlock = currentBlock && currentBlock( root, component );
				if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock ) ifBlock.teardown( detach );
			
			if ( detach ) {
				detachNode( ifBlock_anchor );
			}
		}
	};
}

function renderIfBlock_1$1 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
	div.style.cssText = "width:" + ( root.percent ) + "%";
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = "width:" + ( root.percent ) + "%";
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock_0$2 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress " + ( root.class );
	
	var ifBlock1_anchor = createComment();
	appendNode( ifBlock1_anchor, div );
	
	function getBlock1 ( root ) {
		if ( root.multi ) return renderIfBlock1_0$1;
		return renderIfBlock1_1;
	}
	
	var currentBlock1 = getBlock1( root );
	var ifBlock1 = currentBlock1 && currentBlock1( root, component );
	
	if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress " + ( root.class );
			
			var _currentBlock1 = currentBlock1;
			currentBlock1 = getBlock1( root );
			if ( _currentBlock1 === currentBlock1 && ifBlock1) {
				ifBlock1.update( changed, root );
			} else {
				if ( ifBlock1 ) ifBlock1.teardown( true );
				ifBlock1 = currentBlock1 && currentBlock1( root, component );
				if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock1 ) ifBlock1.teardown( false );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock1_1 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
	div.style.cssText = "width:" + ( root.percent ) + "%";
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = "width:" + ( root.percent ) + "%";
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock1_0$1 ( root, component ) {
	var yield_anchor = createComment();

	return {
		mount: function ( target, anchor ) {
			insertNode( yield_anchor, target, anchor );
			component._yield && component._yield.mount( target, yield_anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( yield_anchor );
			}
		}
	};
}

function Progress ( options ) {
	options = options || {};
	this._state = Object.assign( template$42.data(), options.data );
	applyComputations$1( this._state, this._state, {}, true );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$43( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Progress.prototype = Object.assign( {}, proto );

Progress.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	applyComputations$1( this._state, newState, oldState, false );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Progress.prototype.teardown = Progress.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$43 = (function () {
  return {
    data() {
      return {
        class: '',
        noGutters: false
      }
    }
  };
}());

function renderMainFragment$44 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "row" + ( root.noGutters ? ' no-gutters' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "row" + ( root.noGutters ? ' no-gutters' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Row ( options ) {
	options = options || {};
	this._state = Object.assign( template$43.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$44( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Row.prototype = Object.assign( {}, proto );

Row.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Row.prototype.teardown = Row.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$44 = (function () {
  // TODO remove duplication of table above
  return {
    data() {
      return {
        class: '',
        size: null,
        bordered: false,
        striped: false,
        inverse: false,
        hover: false,
        reflow: false
      }
    }
  }
}());

function renderMainFragment$45 ( root, component ) {
	var ifBlock_anchor = createComment();
	
	function getBlock ( root ) {
		if ( root.responsive ) return renderIfBlock_0$3;
		return renderIfBlock_1$2;
	}
	
	var currentBlock = getBlock( root );
	var ifBlock = currentBlock && currentBlock( root, component );

	return {
		mount: function ( target, anchor ) {
			insertNode( ifBlock_anchor, target, anchor );
			if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			var _currentBlock = currentBlock;
			currentBlock = getBlock( root );
			if ( _currentBlock === currentBlock && ifBlock) {
				ifBlock.update( changed, root );
			} else {
				if ( ifBlock ) ifBlock.teardown( true );
				ifBlock = currentBlock && currentBlock( root, component );
				if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock ) ifBlock.teardown( detach );
			
			if ( detach ) {
				detachNode( ifBlock_anchor );
			}
		}
	};
}

function renderIfBlock_1$2 ( root, component ) {
	var table = createElement( 'table' );
	table.className = "table" + ( root.size ? ` table-${root.size}` : '' ) + ( root.bordered ? ' table-bordered' : '' ) + ( root.striped ? ' table-striped' : '' ) + ( root.inverse ? ' table-inverse' : '' ) + ( root.hover ? ' table-hover' : '' ) + ( root.reflow ? ' table-reflow' :'' ) + "\n   " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, table );

	return {
		mount: function ( target, anchor ) {
			insertNode( table, target, anchor );
			component._yield && component._yield.mount( table, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			table.className = "table" + ( root.size ? ` table-${root.size}` : '' ) + ( root.bordered ? ' table-bordered' : '' ) + ( root.striped ? ' table-striped' : '' ) + ( root.inverse ? ' table-inverse' : '' ) + ( root.hover ? ' table-hover' : '' ) + ( root.reflow ? ' table-reflow' :'' ) + "\n   " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( table );
			}
		}
	};
}

function renderIfBlock_0$3 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "table-responsive";
	
	var table = createElement( 'table' );
	table.className = "table" + ( root.size ? ` table-${root.size}` : '' ) + ( root.bordered ? ' table-bordered' : '' ) + ( root.striped ? ' table-striped' : '' ) + ( root.inverse ? ' table-inverse' : '' ) + ( root.hover ? ' table-hover' : '' ) + ( root.reflow ? ' table-reflow' :'' ) + "\n   " + ( root.class );
	
	appendNode( table, div );
	var yield_anchor = createComment();
	appendNode( yield_anchor, table );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( table, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			table.className = "table" + ( root.size ? ` table-${root.size}` : '' ) + ( root.bordered ? ' table-bordered' : '' ) + ( root.striped ? ' table-striped' : '' ) + ( root.inverse ? ' table-inverse' : '' ) + ( root.hover ? ' table-hover' : '' ) + ( root.reflow ? ' table-reflow' :'' ) + "\n   " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Table ( options ) {
	options = options || {};
	this._state = Object.assign( template$44.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$45( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Table.prototype = Object.assign( {}, proto );

Table.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Table.prototype.teardown = Table.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

exports.Alert = Alert;
exports.Badge = Badge;
exports.Breadcrumb = Breadcrumb;
exports.BreadcrumbItem = BreadcrumbItem;
exports.Button = Button;
exports.ButtonGroup = ButtonGroup;
exports.ButtonToolbar = ButtonToolbar;
exports.Card = Card;
exports.CardBlock = CardBlock;
exports.CardColumns = CardColumns;
exports.CardDeck = CardDeck;
exports.CardFooter = CardFooter;
exports.CardGroup = CardGroup;
exports.CardHeader = CardHeader;
exports.CardImgOverlay = CardImgOverlay;
exports.CardSubtitle = CardSubtitle;
exports.CardText = CardText;
exports.CardTitle = CardTitle;
exports.Close = Close;
exports.Col = Col;
exports.Container = Container;
exports.Form = Form;
exports.FormFeedback = FormFeedback;
exports.FormGroup = FormGroup;
exports.FormText = FormText;
exports.Icon = Icon;
exports.InputGroup = InputGroup;
exports.InputGroupAddon = InputGroupAddon;
exports.Jumbotron = Jumbotron;
exports.ListGroup = ListGroup;
exports.ListGroupItem = ListGroupItem;
exports.ListGroupItemHeading = ListGroupItemHeading;
exports.ListGroupItemText = ListGroupItemText;
exports.Media = Media;
exports.MediaBody = MediaBody;
exports.ModalFooter = ModalFooter;
exports.NavDropdown = NavDropdown;
exports.Nav = Nav;
exports.NavItem = NavItem;
exports.NavbarBrand = NavbarBrand;
exports.Pagination = Pagination;
exports.PaginationItem = PaginationItem;
exports.PaginationLink = PaginationLink;
exports.Progress = Progress;
exports.Row = Row;
exports.Table = Table;
